==> ejc-quality-impl-3.0.0-20240312.094346-9-sources.jar: com/ejianc/business/inspect/vo/IdentifyDetailVO.java <==
package com.ejianc.business.inspect.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 重大危险源动态辨识子实体
 *
 * @author generator
 *
 */
public class IdentifyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long identifyId; // 主表主键
    private String dangerCategory; // 危险源类别
    private String workArea; // 作业区域
    private String dangerName; // 危险源名称
    private String dangerLevel; // 危险源级别
    private String damageType; // 伤害方式
    private String crashType; // 事故类型
    private BigDecimal lEvaluate; // l评价
    private BigDecimal eEvaluate; // e评价
    private BigDecimal cEvaluate; // c评价
    private BigDecimal dEvaluate; // d评价:D=L*E*C
    private String riskLevel; // 风险等级
    private String color; // 颜色标识
    private String resPerson; // 责任人
    private Long controlId; // 档案ID
    private String controlCategory; // 管控项目
    private String controlMeasure; // 管控措施
    private String controlLevel; // 管控层级
    private String memo; // 备注


    public Long getIdentifyId() {
        return identifyId;
    }

    public void setIdentifyId(Long identifyId) {
        this.identifyId = identifyId;
    }
    public String getDangerCategory() {
        return dangerCategory;
    }

    public void setDangerCategory(String dangerCategory) {
        this.dangerCategory = dangerCategory;
    }
    public String getWorkArea() {
        return workArea;
    }

    public void setWorkArea(String workArea) {
        this.workArea = workArea;
    }
    public String getDangerName() {
        return dangerName;
    }

    public void setDangerName(String dangerName) {
        this.dangerName = dangerName;
    }
    public String getDangerLevel() {
        return dangerLevel;
    }

    public void setDangerLevel(String dangerLevel) {
        this.dangerLevel = dangerLevel;
    }
    public String getDamageType() {
        return damageType;
    }

    public void setDamageType(String damageType) {
        this.damageType = damageType;
    }
    public String getCrashType() {
        return crashType;
    }

    public void setCrashType(String crashType) {
        this.crashType = crashType;
    }
    public BigDecimal getLEvaluate() {
        return lEvaluate;
    }

    public void setLEvaluate(BigDecimal lEvaluate) {
        this.lEvaluate = lEvaluate;
    }
    public BigDecimal getEEvaluate() {
        return eEvaluate;
    }

    public void setEEvaluate(BigDecimal eEvaluate) {
        this.eEvaluate = eEvaluate;
    }
    public BigDecimal getCEvaluate() {
        return cEvaluate;
    }

    public void setCEvaluate(BigDecimal cEvaluate) {
        this.cEvaluate = cEvaluate;
    }
    public BigDecimal getDEvaluate() {
        return dEvaluate;
    }

    public void setDEvaluate(BigDecimal dEvaluate) {
        this.dEvaluate = dEvaluate;
    }
    public String getRiskLevel() {
        return riskLevel;
    }

    public void setRiskLevel(String riskLevel) {
        this.riskLevel = riskLevel;
    }
    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }
    public String getResPerson() {
        return resPerson;
    }

    public void setResPerson(String resPerson) {
        this.resPerson = resPerson;
    }
    public Long getControlId() {
        return controlId;
    }

    public void setControlId(Long controlId) {
        this.controlId = controlId;
    }
    public String getControlCategory() {
        return controlCategory;
    }

    public void setControlCategory(String controlCategory) {
        this.controlCategory = controlCategory;
    }
    public String getControlMeasure() {
        return controlMeasure;
    }

    public void setControlMeasure(String controlMeasure) {
        this.controlMeasure = controlMeasure;
    }
    public String getControlLevel() {
        return controlLevel;
    }

    public void setControlLevel(String controlLevel) {
        this.controlLevel = controlLevel;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}

==> ejc-quality-impl-3.0.0-20240320.064052-21-sources.jar: com/ejianc/business/inspect/vo/IdentifyDetailVO.java <==
package com.ejianc.business.inspect.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.math.BigDecimal;


/**
 * 重大危险源动态辨识子实体
 *
 * @author generator
 *
 */
public class IdentifyDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long identifyId; // 主表主键
    private String dangerCategory; // 危险源类别
    private String workArea; // 作业区域
    private String dangerName; // 危险源名称
    private String dangerLevel; // 危险源级别
    private String damageType; // 伤害方式
    private String crashType; // 事故类型
    private BigDecimal levaluate; // l评价
    private BigDecimal eevaluate; // e评价
    private BigDecimal cevaluate; // c评价
    private BigDecimal devaluate; // d评价:D=L*E*C
    private String riskLevel; // 风险等级
    private String color; // 颜色标识
    private String resPerson; // 责任人
    private Long controlId; // 档案ID
    private String controlCategory; // 管控项目
    private String controlMeasure; // 管控措施
    private String controlLevel; // 管控层级
    private String memo; // 备注


    public Long getIdentifyId() {
        return identifyId;
    }

    public void setIdentifyId(Long identifyId) {
        this.identifyId = identifyId;
    }
    public String getDangerCategory() {
        return dangerCategory;
    }

    public void setDangerCategory(String dangerCategory) {
        this.dangerCategory = dangerCategory;
    }
    public String getWorkArea() {
        return workArea;
    }

    public void setWorkArea(String workArea) {
        this.workArea = workArea;
    }
    public String getDangerName() {
        return dangerName;
    }

    public void setDangerName(String dangerName) {
        this.dangerName = dangerName;
    }
    public String getDangerLevel() {
        return dangerLevel;
    }

    public void setDangerLevel(String dangerLevel) {
        this.dangerLevel = dangerLevel;
    }
    public String getDamageType() {
        return damageType;
    }

    public void setDamageType(String damageType) {
        this.damageType = damageType;
    }
    public String getCrashType() {
        return crashType;
    }

    public void setCrashType(String crashType) {
        this.crashType = crashType;
    }
    public String getRiskLevel() {
        return riskLevel;
    }

    public void setRiskLevel(String riskLevel) {
        this.riskLevel = riskLevel;
    }

    public BigDecimal getLevaluate() {
        return levaluate;
    }

    public void setLevaluate(BigDecimal levaluate) {
        this.levaluate = levaluate;
    }

    public BigDecimal getEevaluate() {
        return eevaluate;
    }

    public void setEevaluate(BigDecimal eevaluate) {
        this.eevaluate = eevaluate;
    }

    public BigDecimal getCevaluate() {
        return cevaluate;
    }

    public void setCevaluate(BigDecimal cevaluate) {
        this.cevaluate = cevaluate;
    }

    public BigDecimal getDevaluate() {
        return devaluate;
    }

    public void setDevaluate(BigDecimal devaluate) {
        this.devaluate = devaluate;
    }

    public String getColor() {
        return color;
    }

    public void setColor(String color) {
        this.color = color;
    }
    public String getResPerson() {
        return resPerson;
    }

    public void setResPerson(String resPerson) {
        this.resPerson = resPerson;
    }
    public Long getControlId() {
        return controlId;
    }

    public void setControlId(Long controlId) {
        this.controlId = controlId;
    }
    public String getControlCategory() {
        return controlCategory;
    }

    public void setControlCategory(String controlCategory) {
        this.controlCategory = controlCategory;
    }
    public String getControlMeasure() {
        return controlMeasure;
    }

    public void setControlMeasure(String controlMeasure) {
        this.controlMeasure = controlMeasure;
    }
    public String getControlLevel() {
        return controlLevel;
    }

    public void setControlLevel(String controlLevel) {
        this.controlLevel = controlLevel;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }

}
